Helper function for fast N-mixture calculation
nimNmixPois_logFac(numN, ff)first argument for helper function nimNmixPois_logFac, representing the number of indices in the truncated sum for the N-mixture.
second argument for helper function nimNmixPois_logFac, a derived vector of units calculated partway through the fast N-mixture algorithm.
This is a helper function for the fast N-mixture calculation. It runs an iterative calculation present in all N-mixture varieties. It doesn't have an interpretation outside of that context.